import L from "leaflet";
interface SetMapParams {
    container: string;
    center: L.LatLngExpression;
    zoom: number;
    tileLayer?: string;
    options?: L.MapOptions;
    location?: boolean;
    onLocationUpdate?: (e: L.LocationEvent) => void;
}
interface MarkerControllerParams {
    name: string;
    latlng: L.LatLngExpression;
    iconOptions: L.DivIconOptions;
    markerOptions?: L.MarkerOptions;
    svgCls?: string;
    iconSvg?: string;
}
interface MarkerController {
    name: string;
    marker: L.Marker | L.CircleMarker;
    cls: (cls: string) => void;
    addToCls: (cls: string) => void;
    svgCls: (cls: string) => void;
    addToSvgCls: (cls: string) => void;
}
interface MarkerControllerGroupParams {
    name: string;
    controllers: Record<string, MarkerController>;
}
interface MarkerControllerGroup {
    name: string;
    controllers: Record<string, MarkerController>;
    features: L.FeatureGroup;
}
interface LeafletControllerState {
    zoom: number;
    groups: Record<string, MarkerControllerGroup>;
    markers: Record<string, MarkerController>;
    isReady: boolean;
    canGeolocate: boolean;
    userPosition: L.LocationEvent | null;
}
interface MapController {
    readonly map: L.Map;
    state: LeafletControllerState;
    setMap: (params: SetMapParams) => void;
    resize: () => void;
    clearMapGroups: () => void;
    resetMap: () => void;
    addMarkerController: (c: MarkerController) => void;
    removeMarkerController: (name: string) => void;
    addGroup: (group: MarkerControllerGroup) => void;
    removeGroup: (name: string) => void;
    fitUserLatlng: (latlng: L.LatLngTuple) => void;
    distanceFromUser: (latlng: L.LatLng) => number;
    setLocate: (onLocationUpdate?: (e: L.LocationEvent) => void, onLocationError?: (e: L.ErrorEvent) => void) => void;
    resetLocate: (onLocationUpdate?: (e: L.LocationEvent) => void, onLocationError?: () => void) => void;
}
export { LeafletControllerState, SetMapParams, MarkerControllerParams, MarkerController, MarkerControllerGroupParams, MarkerControllerGroup, MapController, };
